@@ -35,21 +35,12 @@ class DownTimeMiddleware(object):
         if objects.count() > 0:
             # If we have more than one.
             maintenance = objects[0]
-            if maintenance.maintenancefilter_set.count() > 0:
-                for filter in maintenance.maintenancefilter_set.all():
-                    if request.path.startswith(filter.path):
-                        abort_request = True
-                        break
-                else:
-                    # filters specified, but none matched the request
-                    abort_request = False
-            else:
-                # no filters specified, means we abort the request
-                abort_request = True
+
+            abort_request = True
 
             if abort_request:
                 context = {'maintenance': maintenance}
-                return render_to_response('maintenance/downtime.html', context)
+                return render_to_response('down_time/down_time.html', context)
 
         return None
 
